@@ -132,13 +132,18 @@ xmlParserPrintFileContext(xmlParserInputPtr input) {
 		cur--;
 	}
     n = 0;
-	ctnt = content;
+    ctnt = content;
     while ((n++ < 79) && (cur > base) && (*cur != '\n') && (*cur != '\r')) {
 	*ctnt++ = ' ';
 	cur--;
     }
-    *(--ctnt) = '^';
-    *(++ctnt) = 0;
+    if (ctnt > content) {
+	*(--ctnt) = '^';
+	*(++ctnt) = 0;
+    } else {
+	*ctnt = '^';
+	*(++ctnt) = 0;
+    }
     xmlGenericError(xmlGenericErrorContext,"%s\n", content);
 }
 
