@@ -20,12 +20,14 @@ extern "C" {
 #ifndef LIBXML2_COMPILING_MSCCDEF
 extern void xmlCheckVersion(int version);
 #endif /* LIBXML2_COMPILING_MSCCDEF */
-#define LIBXML_DOTTED_VERSION "2.3.8"
-#define LIBXML_VERSION 20308
-#define LIBXML_VERSION_STRING "20308"
-#define LIBXML_TEST_VERSION xmlCheckVersion(20308);
+#define LIBXML_DOTTED_VERSION "2.3.9"
+#define LIBXML_VERSION 20309
+#define LIBXML_VERSION_STRING "20309"
+#define LIBXML_TEST_VERSION xmlCheckVersion(20309);
 
-/*
+/**
+ * WITH_TRIO:
+ *
  * Whether the trio support need to be configured in
  */
 #if 0
@@ -34,7 +36,9 @@ extern void xmlCheckVersion(int version);
 #define WITHOUT_TRIO
 #endif
 
-/*
+/**
+ * LIBXML_FTP_ENABLED:
+ *
  * Whether the FTP support is configured in
  */
 #if 1
@@ -43,7 +47,9 @@ extern void xmlCheckVersion(int version);
 #define LIBXML_FTP_DISABLED
 #endif
 
-/*
+/**
+ * LIBXML_HTTP_ENABLED:
+ *
  * Whether the HTTP support is configured in
  */
 #if 1
@@ -52,7 +58,9 @@ extern void xmlCheckVersion(int version);
 #define LIBXML_HTTP_DISABLED
 #endif
 
-/*
+/**
+ * LIBXML_HTML_ENABLED:
+ *
  * Whether the HTML support is configured in
  */
 #if 1
@@ -61,7 +69,20 @@ extern void xmlCheckVersion(int version);
 #define LIBXML_HTML_DISABLED
 #endif
 
-/*
+/**
+ * LIBXML_CATALOG_ENABLED:
+ *
+ * Whether the Catalog support is configured in
+ */
+#if 1
+#define LIBXML_CATALOG_ENABLED
+#else
+#define LIBXML_CATALOG_DISABLED
+#endif
+
+/**
+ * LIBXML_DOCB_ENABLED:
+ *
  * Whether the SGML Docbook support is configured in
  */
 #if 1
@@ -70,7 +91,9 @@ extern void xmlCheckVersion(int version);
 #define LIBXML_DOCB_DISABLED
 #endif
 
-/*
+/**
+ * LIBXML_XPATH_ENABLED:
+ *
  * Whether XPath is configured in
  */
 #if 1
@@ -79,7 +102,9 @@ extern void xmlCheckVersion(int version);
 #define LIBXML_XPATH_DISABLED
 #endif
 
-/*
+/**
+ * LIBXML_XPTR_ENABLED:
+ *
  * Whether XPointer is configured in
  */
 #if 1
@@ -88,7 +113,9 @@ extern void xmlCheckVersion(int version);
 #define LIBXML_XPTR_DISABLED
 #endif
 
-/*
+/**
+ * LIBXML_XINCLUDE_ENABLED:
+ *
  * Whether XInclude is configured in
  */
 #if 1
@@ -97,7 +124,9 @@ extern void xmlCheckVersion(int version);
 #define LIBXML_XINCLUDE_DISABLED
 #endif
 
-/*
+/**
+ * LIBXML_ICONV_ENABLED:
+ *
  * Whether iconv support is available
  */
 #ifndef WIN32
@@ -108,7 +137,9 @@ extern void xmlCheckVersion(int version);
 #endif
 #endif
 
-/*
+/**
+ * LIBXML_DEBUG_ENABLED:
+ *
  * Whether Debugging module is configured in
  */
 #if 1
@@ -117,7 +148,9 @@ extern void xmlCheckVersion(int version);
 #define LIBXML_DEBUG_DISABLED
 #endif
 
-/*
+/**
+ * DEBUG_MEMORY_LOCATION:
+ *
  * Whether the memory debugging is configured in
  */
 #if 0
@@ -132,6 +165,11 @@ extern void xmlCheckVersion(int version);
 #endif
 #endif
 
+/**
+ * ATTRIBUTE_UNUSED:
+ *
+ * Macro used to signal to GCC unused function parameters
+ */
 #ifdef __GNUC__
 #ifdef HAVE_ANSIDECL_H
 #include <ansidecl.h>
