@@ -167,7 +167,9 @@ struct _xmlXPathAxis {
     xmlXPathAxisFunc func;		/* the search function */
 };
 
-/* 
+/**
+ * xmlXPathContext:
+ *
  * Expression evaluation occurs with respect to a context.
  * he context consists of:
  *    - a node (the context node) 
@@ -229,7 +231,9 @@ struct _xmlXPathContext {
 typedef struct _xmlXPathCompExpr xmlXPathCompExpr;
 typedef xmlXPathCompExpr *xmlXPathCompExprPtr;
 
-/*
+/**
+ * xmlXPathParserContext:
+ *
  * An XPath parser context, it contains pure parsing informations,
  * an xmlXPathContext, and the stack of objects.
  */
@@ -249,7 +253,9 @@ struct _xmlXPathParserContext {
     int xptr;				/* it this an XPointer expression */
 };
 
-/*
+/**
+ * xmlXPathFunction:
+ *
  * An XPath function
  * The arguments (if any) are popped out of the context stack
  * and the result is pushed on the stack.
@@ -266,6 +272,16 @@ typedef void (*xmlXPathFunction) (xmlXPathParserContextPtr ctxt, int nargs);
 /**
  * Objects and Nodesets handling
  */
+
+/* These macros may later turn into functions */
+#define xmlXPathNodeSetGetLength(ns) ((ns) ? (ns)->nodeNr : 0)
+#define xmlXPathNodeSetItem(ns, index)				\
+		((((ns) != NULL) && 				\
+		  ((index) > 0) && ((index) <= (ns)->nodeNr)) ?	\
+		 (ns)->nodeTab[(index)]				\
+		 : NULL)
+
+
 void		   xmlXPathFreeObject		(xmlXPathObjectPtr obj);
 xmlNodeSetPtr	   xmlXPathNodeSetCreate	(xmlNodePtr val);
 void		   xmlXPathFreeNodeSetList	(xmlXPathObjectPtr obj);
@@ -276,6 +292,23 @@ int		   xmlXPathCmpNodes		(xmlNodePtr node1,
 /**
  * Conversion functions to basic types
  */
+int		   xmlXPathCastNumberToBoolean	(double val);
+int		   xmlXPathCastStringToBoolean	(const xmlChar * val);
+int		   xmlXPathCastNodeSetToBoolean	(xmlNodeSetPtr ns);
+int		   xmlXPathCastToBoolean	(xmlXPathObjectPtr val);
+
+double		   xmlXPathCastBooleanToNumber	(int val);
+double		   xmlXPathCastStringToNumber	(const xmlChar * val);
+double		   xmlXPathCastNodeToNumber	(xmlNodePtr node);
+double		   xmlXPathCastNodeSetToNumber	(xmlNodeSetPtr ns);
+double		   xmlXPathCastToNumber		(xmlXPathObjectPtr val);
+
+xmlChar *	   xmlXPathCastBooleanToString	(int val);
+xmlChar *	   xmlXPathCastNumberToString	(double val);
+xmlChar *	   xmlXPathCastNodeToString	(xmlNodePtr node);
+xmlChar *	   xmlXPathCastNodeSetToString	(xmlNodeSetPtr ns);
+xmlChar *	   xmlXPathCastToString		(xmlXPathObjectPtr val);
+
 xmlXPathObjectPtr  xmlXPathConvertBoolean	(xmlXPathObjectPtr val);
 xmlXPathObjectPtr  xmlXPathConvertNumber	(xmlXPathObjectPtr val);
 xmlXPathObjectPtr  xmlXPathConvertString	(xmlXPathObjectPtr val);
