@@ -1,6 +1,6 @@
 /*************************************************************************
  *
- * $Id: strio.h,v 1.2 2001/04/21 16:57:25 breese Exp $
+ * $Id: strio.h,v 1.3 2001/04/30 17:44:44 veillard Exp $
  *
  * Copyright (C) 1998 Bjorn Reese and Daniel Stenberg.
  *
@@ -125,7 +125,7 @@
 enum {
   STRIO_HASH_NONE = 0,
   STRIO_HASH_PLAIN,
-  STRIO_HASH_TWOSIGNED,
+  STRIO_HASH_TWOSIGNED
 };
 
 #if !defined(DEBUG) || defined(__DECC)
